2.1.4. biosimulators_utils.exec_status package — BioSimulators utils 0.1.31 documentation

# 2.1.4. biosimulators_utils.exec_status package

## 2.1.4.1. Submodules

## 2.1.4.2. biosimulators_utils.exec_status.data_model module

Data model for the execution status of COMBINE/OMEX archives

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2020-12-06

Copyright

  2020, Center for Reproducible Biomedical Modeling

License

  MIT

class `biosimulators_utils.exec_status.data_model.` `CombineArchiveExecutionStatus`(status=None, sed_documents=None, out_dir=None)

  Bases: `object`

  Execution status of a COMBINE/OMEX archive

  Attributes

    status (`ExecutionStatus`): execution status of the archive sed_documents (`dict` of `str` to `SedDocumentExecutionStatus`): execution status of each

    > SED document in the archive

    out_dir (`str`): directory to export status

  `export`()

    Write to a file

  `finalize`()

    Mark all unexceuted elements as skipped

  `to_dict`()

    Generate a JSON-compatible representation

    Returns

      JSON-compatible representation

    Return type

      `dict`

class `biosimulators_utils.exec_status.data_model.` `ExecutionStatus`(value)

  Bases: `str`, `enum.Enum`

  Execution status of a component of a COMBINE/OMEX archive

  `FAILED` = 'FAILED'
  `QUEUED` = 'QUEUED'
  `RUNNING` = 'RUNNING'
  `SKIPPED` = 'SKIPPED'
  `SUCCEEDED` = 'SUCCEEDED'

class `biosimulators_utils.exec_status.data_model.` `OutputExecutionStatus`(status=None, document_status=None)

  Bases: `object`

  Execution status of a SED output

  Attributes

    status (`ExecutionStatus`): execution status of the archive document_status (`SedDocumentExecutionStatus`): execution status of parent SED document

  `export`()

    Write to a file

  `finalize`()

    Mark all unexceuted elements as skipped

  `to_dict`()

    Generate a JSON-compatible representation

    Returns

      JSON-compatible representation

    Return type

      `dict`

class `biosimulators_utils.exec_status.data_model.` `Plot2DExecutionStatus`(status=None, curves=None, document_status=None)

  Bases: `biosimulators_utils.exec_status.data_model.OutputExecutionStatus`

  Execution status of a 2D SED plot

  Attributes

    status (`ExecutionStatus`): execution status of the archive curves (`dict` of `str` to `ExecutionStatus`): execution status of each

    > curve

    document_status (`SedDocumentExecutionStatus`): execution status of parent SED document

  `finalize`()

    Mark all unexceuted elements as skipped

  `to_dict`()

    Generate a JSON-compatible representation

    Returns

      JSON-compatible representation

    Return type

      `dict`

class `biosimulators_utils.exec_status.data_model.` `Plot3DExecutionStatus`(status=None, surfaces=None, document_status=None)

  Bases: `biosimulators_utils.exec_status.data_model.OutputExecutionStatus`

  Execution status of a 3D SED plot

  Attributes

    status (`ExecutionStatus`): execution status of the archive surfaces (`dict` of `str` to `ExecutionStatus`): execution status of each

    > surface

    document_status (`SedDocumentExecutionStatus`): execution status of parent SED document

  `finalize`()

    Mark all unexceuted elements as skipped

  `to_dict`()

    Generate a JSON-compatible representation

    Returns

      JSON-compatible representation

    Return type

      `dict`

class `biosimulators_utils.exec_status.data_model.` `ReportExecutionStatus`(status=None, data_sets=None, document_status=None)

  Bases: `biosimulators_utils.exec_status.data_model.OutputExecutionStatus`

  Execution status of a SED report

  Attributes

    status (`ExecutionStatus`): execution status of the archive data_sets (`dict` of `str` to `ExecutionStatus`): execution status of each

    > data set

    document_status (`SedDocumentExecutionStatus`): execution status of parent SED document

  `finalize`()

    Mark all unexceuted elements as skipped

  `to_dict`()

    Generate a JSON-compatible representation

    Returns

      JSON-compatible representation

    Return type

      `dict`

class `biosimulators_utils.exec_status.data_model.` `SedDocumentExecutionStatus`(status=None, tasks=None, outputs=None, combine_archive_status=None)

  Bases: `object`

  Execution status of a SED document

  Attributes

    status (`ExecutionStatus`): execution status of the archive tasks (`dict` of `str` to `TaskExecutionStatus`): execution status of each

    > task

    outputs (`dict` of `str` to `OutputExecutionStatus`): execution status of each

      output

    combine_archive_status (`CombineArchiveExecutionStatus`): execution status of parent COMBINE/OMEX archive

  `export`()

    Write to a file

  `finalize`()

    Mark all unexceuted elements as skipped

  `to_dict`()

    Generate a JSON-compatible representation

    Returns

      JSON-compatible representation

    Return type

      `dict`

class `biosimulators_utils.exec_status.data_model.` `TaskExecutionStatus`(status=None, document_status=None)

  Bases: `object`

  Execution status of a SED task

  Attributes

    status (`ExecutionStatus`): execution status of the task document_status (`SedDocumentExecutionStatus`): execution status of parent SED document

  `export`()

    Write to a file

  `finalize`()

    Mark all unexceuted elements as skipped

  `to_dict`()

    Generate a JSON-compatible representation

    Returns

      JSON-compatible representation

    Return type

      `dict`

## 2.1.4.3. biosimulators_utils.exec_status.utils module

Utilities for working with COMBINE/OMEX archives

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2020-12-06

Copyright

  2020, Center for Reproducible Biomedical Modeling

License

  MIT

`biosimulators_utils.exec_status.utils.` `init_combine_archive_exec_status`(archive, archive_dir, supported_features=(<class 'biosimulators_utils.combine.data_model.CombineArchive'>, <class 'biosimulators_utils.sedml.data_model.SedDocument'>, <class 'biosimulators_utils.sedml.data_model.Task'>, <class 'biosimulators_utils.sedml.data_model.Report'>))

  Initialize the execution status of the SED documents in a COMBINE/OMEX archive

  Parameters

    - archive (`CombineArchive`) – COMBINE/OMEX archive

    - archive_dir (`str`) – path where the content of the archive is located

    - supported_features (`list` of `type`, optional) – list of supported SED elements. Default: COMBINE/OMEX archives, SED documents, SED tasks, and SED reports

  Returns

    initial execution status of the SED documents in an archive

  Return type

    `CombineArchiveExecutionStatus`